pub struct UmaDB { /* private fields */ }Expand description
EventStore implementing the DCBEventStoreSync interface
Implementations
Sourceimpl UmaDB
impl UmaDB
Sourcepub fn new<P: AsRef<Path>>(path: P) -> DCBResult<Self>
pub fn new<P: AsRef<Path>>(path: P) -> DCBResult<Self>
Create a new EventStore at the given directory or file path. If a directory path is provided, a file named “uma.db” will be used inside it.
pub fn from_arc(mvcc: Arc<Mvcc>) -> Self
Sourcepub fn append_batch(
&self,
items: Vec<(Vec<DCBEvent>, Option<DCBAppendCondition>)>,
force_sequential_read: bool,
) -> DCBResult<Vec<DCBResult<u64>>>
pub fn append_batch( &self, items: Vec<(Vec<DCBEvent>, Option<DCBAppendCondition>)>, force_sequential_read: bool, ) -> DCBResult<Vec<DCBResult<u64>>>
Appends a batch of (events, condition) using a single writer/transaction. For each item, behaves like append():
- If condition is Some and matches any events (considering uncommitted writes), returns Err(IntegrityError) for that item and continues.
- If events is empty, returns Ok(0) for that item and continues.
- Otherwise performs unconditional append and records Ok(last_position) for that item.
At the end, commits the writer once. If commit fails, returns the commit error and discards per-item results.