pub struct HeaderNode {
pub tsn: Tsn,
pub free_lists_tree_root_id: PageID,
pub events_tree_root_id: PageID,
pub tags_tree_root_id: PageID,
pub next_page_id: PageID,
pub next_position: Position,
}Fields
tsn: Tsnfree_lists_tree_root_id: PageIDevents_tree_root_id: PageIDnext_page_id: PageIDnext_position: PositionImplementations
Sourceimpl HeaderNode
impl HeaderNode
pub fn default() -> Self
Sourcepub fn serialize_into(&self, buf: &mut [u8]) -> usize
pub fn serialize_into(&self, buf: &mut [u8]) -> usize
Writes the serialized HeaderNode into the provided buffer and returns the number of bytes written (48). The buffer must be at least 48 bytes long.
Sourcepub fn from_slice(slice: &[u8]) -> DCBResult<Self>
pub fn from_slice(slice: &[u8]) -> DCBResult<Self>
Creates a HeaderNode from a byte slice Expects a slice with 48 bytes:
- 8 bytes for tsn
- 8 bytes for next_page_id
- 8 bytes for free_lists_tree_root_id
- 8 bytes for events_tree_root_id
- 8 bytes for tags_tree_root_id
- 8 bytes for next_position
Arguments
slice- The byte slice to deserialize from
Returns
Result<Self>- The deserialized HeaderNode or an error